KeyMigrationHelper class
Utilitaire de migration pour faciliter la transition vers la nouvelle nomenclature
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkForLegacyKeys(
List< String> keys) → void - Affiche un avertissement si des clés héritées sont détectées
-
isLegacyKey(
String key) → bool - Vérifie si une clé utilise l'ancienne nomenclature
-
migrateKeyboardData(
List< String> oldKeys) → List<SecretKeyboardData> - Migre une liste complète de touches
-
migrateKeyData(
String oldKey) → SecretKeyboardData - Convertit les anciens codes de touches vers la nouvelle nomenclature